#include <iostream>                             // Standardstream-Funktionaliät einbinden
#include <fstream>                              // ofstream und ifstream einbinden
#include <vector>
using namespace std;

extern TRandom *gRandom;
extern TBenchmark *gBenchmark;
extern TSystem *gSystem;


void  Plot_IntegratedPi0Yield(const char *input = "RB-data-AnalysisResults", const char *path = "./", const char *suffix = "gif"){	
	
  gROOT->Reset();
  gROOT->SetStyle("Plain");
  gStyle->SetOptStat(0);	
	
  // Which file you want to analyse
  //Char_t filename_input1[100] = (Form("%s%s",path,input1));

  cout<<"Path is :"<<path<<endl;

  TString fileName = Form("%s%s.dat",path,input);

  vector<TString>  inputVector;
  vector<TString>  cutVector;
  vector<Double_t> nGoodEvents;
  vector<Double_t> Reco;
  vector<Double_t> Reco_error;
  vector<Double_t> Background;
  vector<Double_t> Background_error;
  vector<Double_t> Mass;
  vector<Double_t> Mass_error;
  vector<Double_t> FWHM;
  vector<Double_t> FWHM_error;
  vector<Double_t> nPi0_MC;
  vector<Double_t> nPi0_MC_error;
	
  ifstream in;
  in.open(fileName.Data(),ios_base::in);
  cout<<"Open the file: "<<fileName.Data()<<endl;
	
  while(!in.eof()){
    string tmpStr;
    Double_t tmpDouble;

    in >> tmpStr;
    inputVector.push_back(tmpStr);
    in >> tmpStr;
    cutVector.push_back(tmpStr);
    in >> tmpDouble;
    nGoodEvents.push_back(tmpDouble);
    in >> tmpDouble;
    Reco.push_back(tmpDouble);
    in >> tmpDouble;
    Reco_error.push_back(tmpDouble);
    in >> tmpDouble;
    Background.push_back(tmpDouble);
    in >> tmpDouble;
    Background_error.push_back(tmpDouble);
    in >> tmpDouble;
    Mass.push_back(tmpDouble);
    in >> tmpDouble;
    Mass_error.push_back(tmpDouble);
    in >> tmpDouble;
    FWHM.push_back(tmpDouble);
    in >> tmpDouble;
    FWHM_error.push_back(tmpDouble);
    in >> tmpDouble;
    nPi0_MC.push_back(tmpDouble);
    in >> tmpDouble;
    nPi0_MC_error.push_back(tmpDouble);
  }
  in.close();
	
  cout<<"The values are read"<<endl;

  TH1F *histYield = new TH1F("Yield","",10,0.,10.);
  TH1F *histSignificance = new TH1F("Significance","",10,0.,10.);
  TH1F *histMass = new TH1F("Mass","",10,0.,10.);
  TH1F *histFWHM = new TH1F("FWHM","",10,0.,10.);

  if(nPi0_MC != 0){
    TH1F *histEff = new TH1F("histEff","",10,0.,10.);
  }
	
	
  for(Int_t i = 1; i < inputVector.size(); i++){
		
    if(nGoodEvents[i-1] == 0){
      cout<<"Warning:  nGoodEvents["<<i-1<<"]=0"<<endl;
    }
    else{
      Double_t Yield = (Reco[i-1]-Background[i-1])/nGoodEvents[i-1];
      Double_t Yield_error = sqrt(Reco_error[i-1]*Reco_error[i-1] + Background_error[i-1]*Background_error[i-1])/nGoodEvents[i-1];
      histYield->SetBinContent(i,Yield);
      histYield->SetBinError(i,Yield_error);
      histYield->GetXaxis()->SetBinLabel(i,cutVector[i-1].Data());
      
      histMass->SetBinContent(i,Mass[i-1]);
      histMass->SetBinError(i,Mass_error[i-1]);
      histMass->GetXaxis()->SetBinLabel(i,cutVector[i-1].Data());
      
      histFWHM->SetBinContent(i,FWHM[i-1]/2.36);
      histFWHM->SetBinError(i,FWHM_error[i-1]/2.36);
      histFWHM->GetXaxis()->SetBinLabel(i,cutVector[i-1].Data());
    }

    if(Background[i-1]==0){
      cout<<"Warning: Background["<<i-1<<"]=0"<<endl;
    }
    else{	
      cout<<"BG good"<<endl;
      Double_t Sign = Reco[i-1]/sqrt(Background[i-1]);
      Double_t Sign_error = sqrt( pow(Reco_error[i-1]/sqrt(Background[i-1]),2) + pow( -0.5 * Reco[i-1]/pow(Background[i-1],1.5) * Background_error[i-1],2) );
      histSignificance->SetBinContent(i,Sign);
      histSignificance->SetBinError(i,Sign_error);
      histSignificance->GetXaxis()->SetBinLabel(i,cutVector[i-1].Data());
    }
    if(nPi0_MC[i-1] == 0){
      cout<<"Warning: nPi0_MC["<<i-1<<"]=0"<<endl;
    }
    else{
      Double_t Eff = Reco[i-1]/nPi0_MC[i-1];
      Double_t Eff_error = sqrt( pow(Reco_error[i-1]/nPi0_MC[i-1],2) + pow(Reco[i-1]/nPi0_MC[i-1]/nPi0_MC[i-1]*nPi0_MC_error[i-1],2)  );		
      histEff->SetBinContent(i,Eff);
      histEff->SetBinError(i,Eff_error);
      histEff->GetXaxis()->SetBinLabel(i,cutVector[i-1].Data());		
    }
  }
	
  cout<<"Loop finished"<<endl;

  //Create summary histograms and write them to file

  // Yield
  c_Yield = new TCanvas("c_Yield","",1000,600);  // gives the page size
  c_Yield->SetTickx();
  c_Yield->SetTicky();
  c_Yield->SetGridx();
  c_Yield->SetGridy();	
  c_Yield->SetFillColor(0);
  c_Yield->SetBottomMargin(0.2);
  histYield->SetTitle(Form("%s",input));
  histYield->SetYTitle("Int. Yield");  
  histYield->GetYaxis()->SetRangeUser(1e-7,1e-3);	
  histYield->SetMarkerStyle(20);  
  histYield->SetMarkerColor(4);  
  histYield->GetYaxis()->SetTitleOffset(1.3);
  histYield->GetXaxis()->LabelsOption("v");
  histYield->GetXaxis()->SetLabelSize(0.05);
  histYield->DrawCopy("E,p");
  c_Yield->Print(Form("%sPi0Yield_%s.%s",path,input,suffix));
  c_Yield->Update();
		
  // Sign
  c_Sign = new TCanvas("c_Sign","",1000,600);  // gives the page size
  c_Sign->SetTickx();
  c_Sign->SetTicky();
  c_Sign->SetGridx();
  c_Sign->SetGridy();	
  c_Sign->SetFillColor(0);
  c_Sign->SetBottomMargin(0.2);
  histSignificance->SetTitle(Form("%s",input));	
  histSignificance->SetYTitle("Significance");  
  //histSignificance->GetYaxis()->SetDecimals();	
  histSignificance->SetMarkerStyle(20);  
  histSignificance->SetMarkerColor(4);  
  histSignificance->GetYaxis()->SetTitleOffset(1.3);
  histSignificance->GetXaxis()->LabelsOption("v");
  histSignificance->GetXaxis()->SetLabelSize(0.05);
  histSignificance->DrawCopy("E,p");
  c_Sign->Print(Form("%sPi0Significance_%s.%s",path,input,suffix));
  c_Sign->Update();
	
	
  // Mass
  c_Mass = new TCanvas("c_Mass","",1000,600);  // gives the page size
  c_Mass->SetTickx();
  c_Mass->SetTicky();
  c_Mass->SetGridx();
  c_Mass->SetGridy();	
  c_Mass->SetFillColor(0);
  c_Mass->SetBottomMargin(0.2);	
  histMass->SetTitle(Form("%s",input));
  histMass->SetYTitle("Mass");  
  histMass->GetYaxis()->SetRangeUser(0.133,0.136);	
  histMass->SetMarkerStyle(20);  
  histMass->SetMarkerColor(4);  
  histMass->GetYaxis()->SetTitleOffset(1.3);
  histMass->GetXaxis()->LabelsOption("v");
  histMass->GetXaxis()->SetLabelSize(0.05);
  histMass->DrawCopy("E,p");
  c_Mass->Print(Form("%sPi0Mass_%s.%s",path,input,suffix));
  c_Mass->Update();
	
	
  // FWHM
  c_FWHM = new TCanvas("c_FWHM","",1000,600);  // gives the page size
  c_FWHM->SetTickx();
  c_FWHM->SetTicky();
  c_FWHM->SetGridx();
  c_FWHM->SetGridy();	
  c_FWHM->SetFillColor(0);
  c_FWHM->SetBottomMargin(0.2);
  histFWHM->SetTitle(Form("%s",input));	
  histFWHM->SetYTitle("FWHM");  
  histFWHM->GetYaxis()->SetRangeUser(0.,0.01);	
  histFWHM->SetMarkerStyle(20);  
  histFWHM->SetMarkerColor(4);  
  histFWHM->GetYaxis()->SetTitleOffset(1.3);
  histFWHM->GetXaxis()->LabelsOption("v");
  histFWHM->GetXaxis()->SetLabelSize(0.05);
  histFWHM->DrawCopy("E,p");
  c_FWHM->Print(Form("%sPi0FWHM_%s.%s",path,input,suffix));
  c_FWHM->Update();
	
	
  // Eff
  if(nPi0_MC != 0){
    c_Eff = new TCanvas("c_Eff","",1000,600);  // gives the page size
    c_Eff->SetTickx();
    c_Eff->SetTicky();
    c_Eff->SetGridx();
    c_Eff->SetGridy();	
    c_Eff->SetFillColor(0);
    c_Eff->SetBottomMargin(0.2);	
    histEff->SetTitle(Form("%s",input));
    histEff->SetYTitle("Reconstr. Eff.");  
    //histEff->GetYaxis()->SetDecimals();	
    histEff->SetMarkerStyle(20);  
    histEff->SetMarkerColor(4);  
    histEff->GetYaxis()->SetTitleOffset(1.3);
    histEff->GetXaxis()->LabelsOption("v");
    histEff->GetXaxis()->SetLabelSize(0.05);
    histEff->DrawCopy("E,p");
    c_Eff->Print(Form("%sPi0Eff_%s.%s",path,input,suffix));
    c_Eff->Update();
  }
}
